import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classname from 'classnames';
import Popover from 'reactstrap/lib/Popover';
import PopoverBody from 'reactstrap/lib/PopoverBody';
import { isNil } from 'ramda';

import './coach-mark-popover.scss';

export class CoachMarkPopover extends Component {
  static propTypes = {
    isOpen: PropTypes.bool.isRequired,
    toggle: PropTypes.func.isRequired,
    target: PropTypes.oneOfType([PropTypes.string, PropTypes.func]).isRequired,
    children: PropTypes.node.isRequired,
    className: PropTypes.string,
    handleMouseLeave: PropTypes.func,
    handleMouseEnter: PropTypes.func,
  };

  static defaultProps = {
    className: '',
    handleMouseLeave: null,
    handleMouseEnter: null,
  };

  state = {
    fade: false,
  };

  componentDidMount() {
    this.fadePopover();
  }

  fadePopover = () => {
    this.setState({ fade: true });
  };

  handleMouseLeave = () => {
    const { handleMouseLeave } = this.props;

    if (!isNil(handleMouseLeave)) {
      handleMouseLeave();
    }
  };

  handleMouseEnter = () => {
    const { handleMouseEnter } = this.props;

    if (!isNil(handleMouseEnter)) {
      handleMouseEnter();
    }
  };

  render() {
    const {
      isOpen,
      toggle,
      target,
      children,
      className,
    } = this.props;
    const { fade } = this.state;

    return (
      <Popover
        className={classname('coach-mark-popover', className, { fade })}
        placement="bottom-start"
        hideArrow={false}
        isOpen={isOpen}
        toggle={toggle}
        target={target}
        onMouseEnter={this.handleMouseEnter}
        onMouseLeave={this.handleMouseLeave}
      >
        <PopoverBody>{children}</PopoverBody>
      </Popover>
    );
  }
}
