import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Container from 'reactstrap/lib/Container';
import Navbar from 'reactstrap/lib/Navbar';
import NavbarBrand from 'reactstrap/lib/NavbarBrand';
import Nav from 'reactstrap/lib/Nav';
import { IconLogoFooter } from '../icons/icon-logo-footer/icon-logo-footer';
import { LangSwitcher } from '../lang-switcher/lang-switcher';
import './footer.scss';

export const Footer = ({
  locale,
  defaultLocales,
  localesIntl,
  domain,
  children,
  className,
}) => (
  <footer className={classNames('footer p-0 border-top bg-white d-flex align-items-center position-absolute w-100', className)}>
    <Container>
      <Navbar className="justify-content-end justify-content-sm-between">
        <NavbarBrand href={`/${locale}`} className="d-none d-sm-inline-block">
          <IconLogoFooter />
        </NavbarBrand>
        <Nav className="align-items-center justify-content-end">
          {children}
          <LangSwitcher
            locale={locale}
            defaultLocales={defaultLocales}
            localesIntl={localesIntl}
            domain={domain}
          />
        </Nav>
      </Navbar>
    </Container>
  </footer>
);

Footer.propTypes = {
  children: PropTypes.node.isRequired,
  locale: PropTypes.string.isRequired,
  domain: PropTypes.string,
  className: PropTypes.string,
  defaultLocales: PropTypes.oneOfType([PropTypes.objectOf(PropTypes.string), PropTypes.arrayOf(PropTypes.string)]),
  localesIntl: PropTypes.string.isRequired,
};

Footer.defaultProps = {
  className: '',
  defaultLocales: undefined,
  domain: undefined,
};
