import React from 'react';
import { InputWithIconBtn } from './input-with-icon-btn';

const value = 'testValue';
const setValue = jest.fn();

describe('<InputWithIconBtn />', () => {
  describe('<InputWithIconBtn /> is disabled', () => {
    let wrapper;

    beforeAll(() => {
      wrapper = shallow((
        <InputWithIconBtn
          buttonText="textButton"
          label="textLabel"
          value={value}
          icon={<span>Icon</span>}
          disabled
        />
      ));
    });

    test('should match snapshot', () => {
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('<InputWithIconBtn /> not disabled', () => {
    let wrapper;

    beforeAll(() => {
      wrapper = shallow((
        <InputWithIconBtn
          buttonText="textButton"
          label="textLabel"
          icon={<span>Icon</span>}
        />
      ));
      setValue.mockReset();
    });

    describe('when onChange', () => {
      test('should trigger onChanged', () => {
        wrapper.find('.change-value').simulate('change', {
          target: {
            value: 'some_value',
          },
        });
        expect(setValue).not.toHaveBeenCalled();
      });
    });

    test('should match snapshot', () => {
      expect(wrapper).toMatchSnapshot();
    });
  });

  describe('<InputWithIconBtn /> with value', () => {
    let wrapper;

    beforeAll(() => {
      wrapper = shallow((
        <InputWithIconBtn
          buttonText="textButton"
          label="textLabel"
          icon={<span>Icon</span>}
          setValue={setValue}
        />
      ));
    });

    describe('when onChange', () => {
      test('should trigger onChanged', () => {
        wrapper.find('.change-value').simulate('change', {
          target: {
            value: 'some_value',
          },
        });
        expect(setValue).toHaveBeenCalledTimes(1);
      });
    });

    describe('when set value is null', () => {
      beforeAll(() => {
        wrapper.setProps({
          setValue: null,
        });
      });

      test('should match snapshot', () => {
        expect(wrapper).toMatchSnapshot();
      });
    });
  });
});
