import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import colors from '../../../theme/js/color-variables';
import './icon-button-loader.scss';

export const PRIMARY_COLOR_PROP = 'primary';
export const LIGHT_COLOR_PROP = 'light';
export const PINK_P30_COLOR_PROP = 'pinkP30';
export const GRAY_DARK_SECONDARY_PROP = 'grayDarkSecondary';

export const SPIN_TEXT_ELEMENT_CLASS = 'spin-neighboring-text';

export const IconButtonLoader = ({ className, color, withAbsolutePosition }) => {
  const fillColor = {
    [PRIMARY_COLOR_PROP]: colors.greenG40,
    [LIGHT_COLOR_PROP]: colors.white,
    [PINK_P30_COLOR_PROP]: colors.pinkP30,
    [GRAY_DARK_SECONDARY_PROP]: colors.grayDarkSecondary,
  }[color];

  return (
    <span className={classNames({ 'spin-absolute-wrapper d-block position-absolute': withAbsolutePosition })}>
      <svg className={classNames('spin', className, { 'align-middle': !withAbsolutePosition })} xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 16 16">
        <path fill={fillColor} fillRule="evenodd" d="M8 16a8 8 0 1 1 8-8h-1a7 7 0 1 0-7 7v1z" />
      </svg>
    </span>
  );
};

IconButtonLoader.propTypes = {
  className: PropTypes.string,
  color: PropTypes.oneOf([
    PRIMARY_COLOR_PROP,
    LIGHT_COLOR_PROP,
    PINK_P30_COLOR_PROP,
    GRAY_DARK_SECONDARY_PROP,
  ]),
  withAbsolutePosition: PropTypes.bool,
};

IconButtonLoader.defaultProps = {
  className: null,
  color: PRIMARY_COLOR_PROP,
  withAbsolutePosition: false,
};
