import React, { Component } from 'react';
import { pick } from 'ramda';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import Modal from 'reactstrap/lib/Modal';
import ModalBody from 'reactstrap/lib/ModalBody';

const MODAL_SHOWN_CLASS = 'modal-shown';

export class ModalWindowUI extends Component {
  static propTypes = {
    id: PropTypes.string.isRequired,
    isOpen: PropTypes.bool,
    openModal: PropTypes.func.isRequired,
    closeModal: PropTypes.func.isRequired,
    onOpened: PropTypes.func,
    bodyClassName: PropTypes.string,
    children: PropTypes.node.isRequired,
    isCentered: PropTypes.bool,
    fade: PropTypes.bool,
    className: PropTypes.string,
    isFullScreenSm: PropTypes.bool,
  };

  static defaultProps = {
    isOpen: false,
    bodyClassName: '',
    isCentered: true,
    fade: false,
    onOpened: null,
    className: '',
    isFullScreenSm: false,
  };

  toggle = () => {
    const {
      isOpen, id, openModal, closeModal,
    } = this.props;

    if (isOpen) {
      closeModal(id);
      document.body.classList.remove(MODAL_SHOWN_CLASS);
    } else {
      openModal(id);
    }
  };

  onOpened = () => {
    const { onOpened } = this.props;

    if (onOpened) {
      onOpened();
    }

    document.body.classList.add(MODAL_SHOWN_CLASS);
  }

  render() {
    const {
      isOpen, children, isCentered, bodyClassName, fade, className, isFullScreenSm, ...props
    } = this.props;

    return (
      <Modal
        isOpen={isOpen}
        fade={fade}
        centered={isCentered}
        toggle={this.toggle}
        external={<button onClick={this.toggle} className="close-button">&times;</button>}
        // Don't allow unwanted props down to reactstrap Modal component
        {...pick(Object.keys(Modal.propTypes), props)}
        onOpened={this.onOpened}
        className={classNames(className, { 'is-full-screen-sm': isFullScreenSm })}
      >
        <ModalBody className={bodyClassName}>
          {children}
        </ModalBody>
      </Modal>
    );
  }
}
