import React from 'react';

import { BuyWithCard } from './buy-with-card';
import { diveFormattedMessages } from '../../../test/unit/helpers/dive-formatted-messages';

import { CHAR_CODES } from '../../../constants';

const props = {
  usdValue: '2',
  scrValue: '233',
  onUsdChange: jest.fn(),
  onScrChange: jest.fn(),
  usdFraction: 2,
  scrFraction: 3,
  isUsdLoading: false,
  isScrLoading: false,
  onBackClick: jest.fn(),
  isLoading: false,
  ethAddress: 'adfasdasd-asd1231',
};
const evt = {
  which: undefined,
  keyCode: CHAR_CODES.NINE,
  preventDefault: jest.fn(),
};
let wrapper;

describe('<BuyWithCard />', () => {
  wrapper = shallow(<BuyWithCard {...props} />);

  test('should match snapshot', () => {
    expect(wrapper).toMatchSnapshot();
    expect(diveFormattedMessages(wrapper)).toMatchSnapshot();
  });

  describe('onKeyPress', () => {
    test('should not trigger `preventDefault`', () => {
      wrapper.instance().onKeyPress(evt);
      evt.keyCode = 1;
      wrapper.instance().onKeyPress(evt);
      expect(evt.preventDefault).toHaveBeenCalledTimes(0);
    });

    test('should trigger `preventDefault`', () => {
      evt.keyCode = 66;
      wrapper.instance().onKeyPress(evt);
      evt.keyCode = 47;
      wrapper.instance().onKeyPress(evt);
      expect(evt.preventDefault).toHaveBeenCalledTimes(2);
    });
  });

  describe('usdChangeHandler', () => {
    test('should not trigger `onUsdChange` prop', () => {
      wrapper.instance().usdChangeHandler({ target: { value: '3.sadas' } });
      expect(props.onUsdChange).toHaveBeenCalledTimes(0);
    });

    test('should trigger `onUsdChange` prop', () => {
      wrapper.instance().usdChangeHandler({ target: { value: '3.3' } });
      expect(props.onUsdChange).toHaveBeenCalledTimes(1);
    });
  });

  describe('scrChangeHandler', () => {
    test('should not trigger `onScrChange` prop', () => {
      wrapper.instance().scrChangeHandler({ target: { value: '3.sadas' } });
      expect(props.onScrChange).toHaveBeenCalledTimes(0);
    });

    test('should trigger `onScrChange` prop', () => {
      wrapper.instance().scrChangeHandler({ target: { value: '3.3' } });
      expect(props.onScrChange).toHaveBeenCalledTimes(1);
    });
  });

  test('onBackClick should trigger `onBackClick` prop', () => {
    wrapper.instance().onBackClick();
    expect(props.onBackClick).toHaveBeenCalledTimes(1);
  });
});
