import React from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import { IconEthLogo } from '../../icons/icon-eth-logo/icon-eth-logo';
import { IconCreditCards } from '../../icons/icon-credit-cards/icon-credit-cards';

import GA from '../../../helpers/ga';

import './choose-payment.scss';

export const ChoosePayment = ({ isEthLogoWhite, onEthClick, onFiatClick }) => {
  function ethClickHandler() {
    GA.event({ category: 'BuySCR', action: '2Choose eth' });
    onEthClick();
  }

  function fiatClickHandler() {
    GA.event({ category: 'BuySCR', action: '2Choose fiat' });
    onFiatClick();
  }

  return (
    <div className="choose-payment text-center">
      <FormattedMessage id="universal.balance.refill.choose-payment-step.title">
        {text => <span className="h3 d-block mb-2">{text}</span>}
      </FormattedMessage>

      <FormattedMessage id="universal.balance.refill.choose-payment-step.subtitle" />

      <div
        className="step mt-4_5 mb-2 d-flex justify-content-center align-items-center border converter-border rounded"
        role="button"
        tabIndex="0"
        onClick={ethClickHandler}
        onKeyPress={ethClickHandler}
      >
        <IconEthLogo isWhite={isEthLogoWhite} />
      </div>

      <div
        className="step d-flex justify-content-center align-items-center border converter-border rounded"
        role="button"
        tabIndex="0"
        onClick={fiatClickHandler}
        onKeyPress={fiatClickHandler}
      >
        <IconCreditCards />
      </div>
    </div>
  );
};

ChoosePayment.propTypes = {
  onEthClick: PropTypes.func.isRequired,
  onFiatClick: PropTypes.func.isRequired,
  isEthLogoWhite: PropTypes.bool,
};

ChoosePayment.defaultProps = {
  isEthLogoWhite: true,
};

