import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import classnames from 'classnames';

import GA from '../../helpers/ga';
import { CHAR_CODES } from '../../constants';
import './services-list.scss';

export class ServicesList extends Component {
  static propTypes = {
    serviceItems: PropTypes.arrayOf(PropTypes.shape({
      link: PropTypes.string.isRequired,
      message: PropTypes.string.isRequired,
      service: PropTypes.string.isRequired,
      icon: PropTypes.node.isRequired,
    })).isRequired,
    hostname: PropTypes.string.isRequired,
    className: PropTypes.string,
  };

  static defaultProps = {
    className: '',
  };

  fireAction = (e) => {
    const action = e.currentTarget.dataset.service;
    GA.event({ category: 'Services', action });
  };

  serviceKeyPress = (e) => {
    const { which, keyCode } = e;
    const charCode = which || keyCode;
    if (charCode === CHAR_CODES.ENTER) {
      this.fireAction(e);
    }
  };

  render() {
    const { serviceItems, hostname, className } = this.props;
    const hostnameRegexp = new RegExp(`^((https?:)?//)?${hostname}`);

    return (
      <div className={classnames('services d-flex flex-wrap align-items-baseline', className)}>
        {
          serviceItems.map(({
            link, message, icon, service,
          }) => {
            const hrefProps = link.match(hostnameRegexp) ? { href: '' } : { href: link, target: '_blank' };

            return (
              <a
                role="button"
                tabIndex="0"
                className="service-item d-flex align-items-center flex-column py-2"
                key={`${link}${message}`}
                data-service={service}
                {...hrefProps}
                onClick={this.fireAction}
                onKeyPress={this.serviceKeyPress}
              >
                {icon}
                <FormattedMessage id={message} />
              </a>
            );
          })
        }
      </div>
    );
  }
}
