import React, { Component, Fragment } from 'react';
import PropTypes from 'prop-types';
import classnames from 'classnames';
import Popover from 'reactstrap/lib/Popover';
import PopoverBody from 'reactstrap/lib/PopoverBody';

import { IconServices } from '../icons/icon-services/icon-services';
import { ServicesList } from '../services-list/services-list';
import GA from '../../helpers/ga';
import './services-menu.scss';

const SERVICES_MENU_ID = 'SERVICES_MENU_ID';

export class ServicesMenu extends Component {
  static propTypes = {
    serviceItems: PropTypes.arrayOf(PropTypes.shape({
      link: PropTypes.string.isRequired,
      message: PropTypes.string.isRequired,
      service: PropTypes.string.isRequired,
      icon: PropTypes.node.isRequired,
    })).isRequired,
    hostname: PropTypes.string.isRequired,
    className: PropTypes.string,
  };

  static defaultProps = {
    className: '',
  };

  state = {
    menuOpen: false,
  };

  toggleMenu = () => {
    if (!this.state.menuOpen) {
      GA.event({ category: 'Services', action: 'Services' });
    }
    this.setState(previousState => ({
      menuOpen: !previousState.menuOpen,
    }));
  };

  render() {
    const { menuOpen } = this.state;
    const { serviceItems, hostname, className } = this.props;

    return (
      <Fragment>
        <div
          role="button"
          tabIndex="0"
          className={classnames('services-menu-icon d-flex', className)}
          onClick={this.toggleMenu}
          onKeyPress={this.toggleMenu}
          id={SERVICES_MENU_ID}
        >
          <IconServices />
        </div>
        <Popover
          placement="bottom-end"
          hideArrow
          isOpen={menuOpen}
          target={SERVICES_MENU_ID}
          toggle={this.toggleMenu}
          className="popover-services-menu mt-2"
        >
          <PopoverBody>
            <ServicesList serviceItems={serviceItems} hostname={hostname} />
          </PopoverBody>
        </Popover>
      </Fragment>
    );
  }
}
